<?php

$XPIndexConf	= Array();
$ApacheConf		= Array();

// Web Directory:
// Relative position to the webroot
$XPIndexConf['Web Directory'] = '/XPindex';

// Hide XPindex Dir
// If true the server will return a blank page if the request is in the webdirectory specified by $XPIndexConf['Web Directory']
$XPIndexConf['Hide XPindex Dir'] = false;

// TaskBar
// never = never draw the taskbar
// readme = only draw the taskbar when there is an README.html file in the directory
// always = always draw the taskbar
$XPIndexConf['TaskBar'] = 'readme';

// User Directories:
// The directory where the userdirs are created (default: /home).
$ApacheConf['User Directories'] = '/home';

// User HTML Directory:
// This is the same entry as can be found in the apache config file (default: public_html).
$ApacheConf['User HTML Directory'] = 'public_html';

// Readme Files:
// This is the same entry as can be found in the apache config file (default: README.html).
$ApacheConf['Readme Files'] = Array(
//	'Filename'				Type,	Show,	$Caption[]
	'README.html' => Array(RF_HTML,	false, 	_("Readme")),
	'file_id.diz' => Array(RF_TEXT,	true, 	"file_id.diz")
);

// Theme selection
$Themes = Array(
	'XP Theme Blue' => Array(
		'Name' => 'xp_blue',
		'Enabled' => true,
		'Default' => true
	),
	'XP Theme Olive' => Array(
		'Name' => 'xp_olive',
		'Enabled' => true,
		'Default' => false
	),
	'XP Theme Silver' => Array(
		'Name' => 'xp_silver',
		'Enabled' => true,
		'Default' => false
	),
	'XP Theme Green' => Array(
		'Name' => 'xp_green',
		'Enabled' => false,
		'Default' => false
	)
);

?>