body {
	padding: 0px;
	margin: 0px;
	height: 100%;
	font-family: sans-serif;
}

div.task-text, div.task-html {
	width: 207px;
	padding: 2px;
	text-align: left;
}

div.task-text {
	overflow: auto;
}

div.task-html {
	overflow: hidden;
}

img {
	border-style: none;
}

table {
	width: 100%;
}

table.main {
	height: 100%;
}

table.status {
	border-top: solid black 1px;
}

table.task {
	position: relative;
	top: 0px;
	margin-top: 10px;
	margin-bottom: 10px;
	left: 12px;
	width: 213px;
}

td {
	padding-top: 2px;
	padding-right: 7px;
	height: 18px;
	white-space: nowrap;
	width: 5%;
}

td.group {
	padding-left: 14px;
	padding-top: 3px;
	padding-bottom: 2px;
}

td.left {
	text-align: left;
}

td.right {
	text-align: right;
}

td.statusbar {
	padding: 0px;
}

td.task {
	padding: 0px;
	margin: 0px;
	border: solid 1px #000000;
	white-space: normal;
	text-align: right;
}

td.taskbar {
	border-right: solid black 1px;
	width: 240px;
	padding: 0px;
	vertical-align: top;
}

th {
	padding: 3px 5px 4px 5px;
	white-space: nowrap;
	width: 150px;

	border-bottom: solid black 1px;
	text-align: left;
}

th.fill {
	width: 100%;
}

th.task {
	border-style: none;
}