a {
	text-decoration: none;
	color: #000000;
	background-color: transparent;
	padding-left: 3px;
	padding-right: 3px;
	padding-top: 1px;
	padding-bottom: 1px;
}

a.head:hover {
	background-color: transparent;
	color: #000000;
	text-decoration: underline;
}

a:hover {
	background-color: #93A070;
	color: #FFFFFF;
}

body {
	background-color: #FFFFFF;
	color: #000000;
	padding: 0px;
	margin: 0px;
	height: 100%;
}

div.task-text, div.task-html {
	font-weight: normal;
	width: 207px;
	padding: 2px;
	text-align: left;
}

div.task-text {
	font-family: Lucida Console, Courier New, Courier, system;
	font-size: 6pt;
	overflow: auto;
}

div.task-html {
	font-family: Tahoma, Verdana, Arial, sans-serif;
	font-size: 8pt;
	overflow: hidden;
}

img {
	width: 16px;
	height: 16px;
	border-style: none;
	border-width: 0px;
	vertical-align: bottom;
	margin-left: 2px;
}

table {
	width: 100%;
}

table.main {
	height: 100%;
}

table.status {
	background-image: url(./status.png);
	background-repeat: repeat-x;
	background-position: left top;
}

table.header {
	background-repeat: repeat-x;
	background-position: left top;
	background-image: url(./header.png);
}

table.task {
	position: relative;
	top: 0px;
	margin-top: 10px;
	margin-bottom: 10px;
	left: 12px;
	width: 213px;
}

td {
	font-family: Tahoma, Verdana, Arial, sans-serif;
	font-size: 8pt;
	font-weight: normal;
	padding-top: 2px;
	padding-right: 7px;
	height: 18px;
	white-space: nowrap;
	width: 5%;
}

td.group {
	font-weight: bold;

	background-image: url(./group.png);
	background-repeat: no-repeat;
	background-position: left bottom;

	padding-left: 14px;
	padding-top: 3px;
	padding-bottom: 2px;
}

th.header-left, th.header-right {
	background-image: url(./header_seperator.png);
	background-repeat: no-repeat;
	background-position: right top;
}

th.header-left {
	text-align: left;
}

th.header-right {
	text-align: right;
}

th.fill {
	width: 100%;
}

td.left {
	text-align: left;
}

td.right {
	text-align: right;
}

td.status {
	background-image: url(./status_seperator.png);
	background-repeat: no-repeat;
	background-position: right bottom;
	padding-left: 4px;
	padding-top: 4px;
	height: 23px;
}

td.statusbar {
	padding: 0px;
}

td.task {
	background-color: #F6F6EC;
	color: #56662D;

	padding: 0px;
	margin: 0px;
	border-right: solid 1px #FFFFFF;
	border-bottom: solid 1px #FFFFFF;
	border-left: solid 1px #FFFFFF;
	white-space: normal;
	text-align: right;
}

td.taskbar {
	background-color: #BCCD9C;
	color: #56662D;

	width: 240px;
	padding: 0px;
	vertical-align: top;
}

th {
	font-family: Tahoma, Verdana, Arial, sans-serif;
	font-size: 8pt;
	font-weight: normal;
	padding: 3px 5px 4px 5px;
	background-repeat: repeat-x;
	background-position: right;
	white-space: nowrap;
	width: 150px;
}

th.task {
	background-image: url(./taskhead.png);
	color: #56662D;

	height: 23px;
	padding-left: 14px;
	font-family: Tahoma, Verdana, Arial, sans-serif;
	font-size: 8pt;
	font-weight: bold;
	text-align: left;
}

thead {
	/* Okay.. this line crashes Mozilla 1.3 */
	/* position: fixed; */
}