<?php

// File Type Constants
define('FT_FILE',				8);
define('FT_DIRECTORY',			4);
define('FT_DIRECTORYUP',		2);
define('FT_DIRECTORYREFRESH',	1);

// Sort Type Constants
define('SORT_TYPE', 		'Description');
define('SORT_NAME', 		'Char');
define('SORT_SIZE', 		'SizeGroup');
define('SORT_MODIFY', 		'ModifyGrp');
define('SORT_ACCESS', 		'AccessGrp');
define('SORT_OWNER', 		'Owner');
define('SORT_GROUP', 		'Group');
define('SORT_PERMISSION',	'Permission');

// Readme File Constants
define('RF_TEXT', 1);
define('RF_HTML', 2);

// Define version
define('XPindex_Author',	'Michaël Hompus');
define('XPindex_AuthorMail','xpindex@hompus.nl');
define('XPindex_URL',		'http://www.hompus.nl/xpindex/');
define('XPindex_Version',	'0.80 Beta 4');
define('XPindex_Date',		'2003-11-19T00:00:00+01:00');

// Extensions
$Extensions = Array(
	'..'			=> _("Parent Folder"),
	'^^DIRECTORY^^'	=> _("File Folder"),
	'aca' 			=> _("Microsoft Agent Character File (HTTP format)"),
	'acg'			=> _("Microsoft Agent Preview File"),
	'acs'			=> _("Microsoft Agent Character File"),
	'aif'	 		=> _("AIFF Format Sound"),
	'aifc'	 		=> _("AIFF Format Sound"),
	'ani' 			=> _("Animated Cursor"),
	'asa' 			=> _("Active Server Pages"),
	'ascx' 			=> _("Web User Control"),
	'asf' 			=> _("Windows Media Audio/Video file"),
	'asmx' 			=> _("Web Service"),
	'asp' 			=> _("Active Server Pages"),
	'aspx' 			=> _("Web Form"),
	'asx' 			=> _("Windows Media Audio/Video playlist"),
	'au'	 		=> _("AU Format Sound"),
	'avi' 			=> _("Video Clip"),
	'avs' 			=> _("AviSynth Script"),
	'aw'	 		=> _("Answer Wizard File"),
	'axt'	 		=> _("AutoRoute Template"),
	'bat' 			=> _("MS-DOS Batch File"),
	'blg'			=> _("Performance Monitor File"),
	'bmp' 			=> _("Bitmap Image"),
	'bpg' 			=> _("Borland Project Group"),
	'cab' 			=> _("Cabinet File"),
	'cat' 			=> _("Security Catalog"),
	'chk' 			=> _("Recovered File Fragments"),
	'chm' 			=> _("Compiled HTML Help file"),
	'cmd'	 		=> _("Windows NT Command Script"),
	'cnf'	 		=> _("SpeedDial"),
	'com' 			=> _("MS-DOS Application"),
	'config' 		=> _("Web Configuration file"),
	'cpl'	 		=> _("Control Panel extension"),
	'crt' 			=> _("Security Certificate"),
	'cs'	 		=> _("C# Source file"),
	'csproj'	 	=> _("C# Project file"),
	'css'	 		=> _("Cascading Style Sheet Document"),
	'csv' 			=> _("Microsoft Office Excel Comma Separated Values File"),
	'cur' 			=> _("Cursor"),
	'db' 			=> _("Data Base File"),
	'dbp'	 		=> _("Visual Studio .NET Database Project"),
	'dfm'	 		=> _("Delphi Form"),
	'disco'			=> _("Web Service Discovery File"),
	'dll'	 		=> _("Application Extension"),
	'doc'	 		=> _("Microsoft Word Document"),
	'dot'	 		=> _("Microsoft Word Template"),
	'dpk'	 		=> _("Delphi Package"),
	'dpr'	 		=> _("Delphi Project"),
	'dps'	 		=> _("DivX Player Skin File"),
	'drv'	 		=> _("Device Driver"),
	'dtq'	 		=> _("SQL Query file"),
	'dun'	 		=> _("Dialup Networking File"),
	'dvr-ms'		=> _("Microsoft Recorded TV Show"),
	'elm'			=> _("Microsoft Office Themes File"),
	'etp'	 		=> _("Enterprise Template Project"),
	'exe'	 		=> _("Application"),
	'fbk'			=> _("Microsoft Business Solutions-Navision Backup"),
	'fdb'			=> _("Microsoft Business Solutions-Database File"),
	'flf'			=> _("Microsoft Business Solutions-License File"),
	'fnd'			=> _("Saved Search"),
	'fob'			=> _("Microsoft Business Solutions-Object File"),
	'fon'			=> _("Font file"),
	'gif'	 		=> _("GIF Image"),
	'gz'	 		=> _("GZIP Compressed Document"),
	'hlp'	 		=> _("Help File"),
	'hol'	 		=> _("Microsoft Office Outlook Holidays"),
	'hta'			=> _("HTML Application"),
	'htm'	 		=> _("HTML Document"),
	'html'	 		=> _("HTML Document"),
	'htt'	 		=> _("HyperText Template"),
	'hxc'	 		=> _("Microsoft Help Collection Definition File"),
	'hxi'	 		=> _("Microsoft Help Compiled Index"),
	'hxk'	 		=> _("Microsoft Help Index File"),
	'hxs'	 		=> _("Compiled Microsoft Help file"),
	'hxt'	 		=> _("Microsoft Help Table of Contents File"),
	'icm'	 		=> _("ICC Profile"),
	'ico'	 		=> _("Icon"),
	'inf'	 		=> _("Setup Information"),
	'ini'	 		=> _("Configuration Settings"),
	'ins'	 		=> _("Internet Communication Settings"),
	'its'	 		=> _("Internet Document Set"),
	'iqy'	 		=> _("Microsoft Office Excel Web Query File"),
	'isp'	 		=> _("Internet Communication Settings"),
	'iss'	 		=> _("Unattended Setup File"),
	'jar'	 		=> _("Executable Jar File"),
	'jbf'	 		=> _("Paint Shop Pro 7 Browser Cache File"),
	'jfif'	 		=> _("JPEG Image"),
	'jif'	 		=> _("JPEG Image"),
	'job'	 		=> _("Task Object"),
	'jpeg'	 		=> _("JPEG Image"),
	'jpg'	 		=> _("JPEG Image"),
	'js'	 		=> _("JScript Script File"),
	'jse'	 		=> _("JScript Encoded Script File"),
	'ldf'	 		=> _("Database File"),
	'lex'			=> _("Dictionary File"),
	'lnk'			=> _("Shortcut"),
	'm1v'	 		=> _("Movie File (mpeg)"),
	'mad'	 		=> _("Microsoft Office Access Module Shortcut"),
	'mat'	 		=> _("Microsoft Office Access Table Shortcut"),
	'mdb'	 		=> _("Microsoft Office Access Application"),
	'mdf'	 		=> _("Database File"),
	'mht'	 		=> _("MHTML Document"),
	'mid'	 		=> _("MIDI Sequence"),
	'midi'	 		=> _("MIDI Sequence"),
	'mml'	 		=> _("Media Catalog File"),
	'mmw'	 		=> _("Media Catalog File"),
	'mp2'	 		=> _("Movie File (mpeg)"),
	'mp3'	 		=> _("MP3 audio file (mp3)"),
	'mpa'	 		=> _("Movie File (mpeg)"),
	'mpe'	 		=> _("Movie File (mpeg)"),
	'mpeg'	 		=> _("Movie File (mpeg)"),
	'mpg'	 		=> _("Movie File (mpeg)"),
	'msc'	 		=> _("Microsoft Common Console Document"),
	'msg'			=> _("Outlook Item"),
	'msi'	 		=> _("Windows Installer Package"),
	'msstyles'	 	=> _("Windows Visual Style File"),
	'ncd'			=> _("Nero Cover Designer Document"),
	'nct'			=> _("Nero Cover Designer Template"),
	'nfo'	 		=> _("MSInfo Document"),
	'ocx'	 		=> _("ActiveX Control"),
	'odc'	 		=> _("Microsoft Office Data Connection"),
	'opc'	 		=> _("Microsoft Clean-up Wizard File"),
	'ost'	 		=> _("Office Data File"),
	'otf'			=> _("OpenType Font file"),
	'pas'	 		=> _("Delphi Source File"),
	'pdf'	 		=> _("Adobe Acrobat Document"),
	'pdi'	 		=> _("Microsoft Visual Studio .NET Setup PDI file"),
	'pfm'	 		=> _("Type 1 Font file"),
	'php'	 		=> _("PHP Script File"),
	'php3'	 		=> _("PHP Script File"),
	'php4'	 		=> _("PHP Script File"),
	'phps'	 		=> _("PHP Script Source File"),
	'phtml'	 		=> _("PHP Script File"),
	'pif'			=> _("Shortcut to MS-DOS Program"),
	'pip'			=> _("Microsoft Office Settings File"),
	'pmc'	 		=> _("Performance Monitor File"),
	'pnf'	 		=> _("Precompiled Setup Information"),
	'png'	 		=> _("PNG Image"),
	'pot'			=> _("Microsoft PowerPoint Template"),
	'ppk'			=> _("PuTTY Private Key File"),
	'ppt'			=> _("Microsoft PowerPoint Presentation"),
	'prc'			=> _("SQL Stored Procedure Script file"),
	'prf'			=> _("Microsoft Office Outlook Profile Settings"),
	'psp'	 		=> _("Paint Shop Pro 7 Image"),
	'pst'	 		=> _("Office Data File"),
	'pub'			=> _("Microsoft Office Publisher Document"),
	'rar'	 		=> _("RAR Archive"),
	'rc'	 		=> _("Resource Script"),
	'rct'	 		=> _("Resource Compiler Script"),
	'rdp'	 		=> _("Remote Desktop Connection"),
	'reg'	 		=> _("Registration Entries"),
	'res'	 		=> _("Compiled Resource Script"),
	'resx' 			=> _(".NET XML Resource Template"),
	'rll'	 		=> _("Resource File"),
	'rmi'	 		=> _("MIDI Sequence"),
	'rpm'			=> _("Red Hat Package Manager file"),
	'rtf'	 		=> _("Rich Text Format"),
	'scf'	 		=> _("Windows Explorer Command"),
	'scr'	 		=> _("Screen Saver"),
	'sdb'	 		=> _("Appfix Package"),
	'sdl'			=> _("Web Service Description Language"),
	'shtm'	 		=> _("HTML Document"),
	'shtml'	 		=> _("HTML Document"),
	'sln' 			=> _("Visual Studio Solution"),
	'snd'	 		=> _("AU Format Sound"),
	'spl'			=> _("Shockwave Flash Object"),
	'sql'	 		=> _("SQL Script File"),
	'suo' 			=> _("Visual Studio Solution User Options"),
	'swf'			=> _("Shockwave Flash Object"),
	'sys'			=> _("System file"),
	'tar'	 		=> _("TAR Archive"),
	'tdf'	 		=> _("SQL Profiler - trace definitions file"),
	'tdl'	 		=> _("Template Description Language File"),
	'tgz'	 		=> _("GZIP Compressed TAR Archive"),
	'theme'	 		=> _("Windows Theme File"),
	'tif'			=> _("TIF Image"),
	'tiff'			=> _("TIF Image"),
	'ttf'	 		=> _("TrueType Font file"),
	'txt'	 		=> _("Text Document"),
	'url'	 		=> _("Internet Shortcut"),
	'vb' 			=> _("Visual Basic Source"),
	'vbproj' 		=> _("Visual Basic .NET Project"),
	'vbs' 			=> _("VBScript Script File"),
	'vcf' 			=> _("vCard File"),
	'vsdisco' 		=> _("VS.NET Web Service Dynamic Discovery File"),
	'vsmacros' 		=> _("Visual Studio Macro Project (Binary)"),
	'vxd' 			=> _("Virtual device driver"),
	'wab'			=> _("Address Book File"),
	'wav'	 		=> _("Wave Sound"),
	'wax'	 		=> _("Windows Media Audio shortcut"),
	'wm'	 		=> _("Windows Media Audio/Video file"),
	'wma'	 		=> _("Windows Media Audio file"),
	'wmf'	 		=> _("WMF Image"),
	'wmv'	 		=> _("Windows Media Audio/Video file"),
	'wmx' 			=> _("Windows Media Audio/Video playlist"),
	'wpl'	 		=> _("Windows Media playlist"),
	'wri' 			=> _("Write Document"),
	'wsc'	 		=> _("Windows Script Component"),
	'wsf' 			=> _("Windows Script File"),
	'wvx' 			=> _("Windows Media Audio/Video playlist"),
	'xdr'	 		=> _("XML-Data Reduced Schema"),
	'xla'	 		=> _("Microsoft Office Excel Add-In"),
	'xls'	 		=> _("Microsoft Excel Worksheet"),
	'xml'	 		=> _("XML Document"),
	'xsd'	 		=> _("XML Schema"),
	'xsl'	 		=> _("XSL Stylesheet"),
	'xslt'	 		=> _("XSL Tranformation"),
	'xsn'	 		=> _("Microsoft Office InfoPath Form Template"),
	'z'				=> _("Compressed Document"),
	'zip'	 		=> _("Compressed (zipped) Folder"),
	'zup'	 		=> _("Microsoft Business Solutions-Navision User Preferences")
);

// Incremental Extensions
$IncrementalExtensions = Array(
	'r' => 'rar',
	'z' => 'zip'
);

// Icons
$Icons = Array(
	'.' 			=> 'refresh.png',
	'..' 			=> 'mapup.png',
	'^^BLANKICON^^'	=> 'none.png',
	'^^DIRECTORY^^'	=> 'map.png',
	'aca' 			=> 'aca.png',
	'acg' 			=> 'aca.png',
	'acs' 			=> 'aca.png',
	'aif' 			=> 'avi.png',
	'aifc' 			=> 'avi.png',
	'api' 			=> 'api.png',
	'ascx' 			=> 'ascx.png',
	'asf' 			=> 'avi.png',
	'asmx' 			=> 'asmx.png',
	'asp' 			=> 'asp.png',
	'aspx' 			=> 'aspx.png',
	'asx' 			=> 'avi.png',
	'au' 			=> 'avi.png',
	'avi' 			=> 'avi.png',
	'avs' 			=> 'avs.png',
	'axt' 			=> 'axt.png',
	'bat' 			=> 'bat.png',
	'blg' 			=> 'pmc.png',
	'bmp' 			=> 'bmp.png',
	'bpg' 			=> 'dpr.png',
	'cab' 			=> 'cab.png',
	'cat' 			=> 'cat.png',
	'chk' 			=> 'dll.png',
	'chm' 			=> 'chm.png',
	'cmd' 			=> 'bat.png',
	'cnf' 			=> 'cnf.png',
	'com' 			=> 'exe.png',
	'config' 		=> 'config.png',
	'cpl' 			=> 'cpl.png',
	'crt' 			=> 'crt.png',
	'cs' 			=> 'cs.png',
	'css' 			=> 'ini.png',
	'csproj' 		=> 'csproj.png',
	'csv' 			=> 'csv.png',
	'db' 			=> 'dll.png',
	'dbp' 			=> 'dbp.png',
	'dfm' 			=> 'dpr.png',
	'disco' 		=> 'disco.png',
	'diz' 			=> 'txt.png',
	'dll' 			=> 'dll.png',
	'doc' 			=> 'doc.png',
	'dot' 			=> 'dot.png',
	'dpk' 			=> 'dpk.png',
	'dpr' 			=> 'dpr.png',
	'dps'			=> 'dps.png',
	'dtq' 			=> 'dtq.png',
	'dun' 			=> 'dun.png',
	'dvr-ms'		=> 'avi.png',
	'elm' 			=> 'prf.png',
	'etp' 			=> 'etp.png',
	'exe' 			=> 'exe.png',
	'fbk' 			=> 'fdb.png',
	'fdb' 			=> 'fdb.png',
	'flf' 			=> 'fdb.png',
	'fnd' 			=> 'fnd.png',
	'fob' 			=> 'fdb.png',
	'fon' 			=> 'fon.png',
	'gz' 			=> 'zip.png',
	'gif' 			=> 'gif.png',
	'hlp' 			=> 'hlp.png',
	'hol' 			=> 'hol.png',
	'html'			=> 'html.png',
	'htm' 			=> 'html.png',
	'htt' 			=> 'htt.png',
	'hxc' 			=> 'hxc.png',
	'hxi' 			=> 'hxi.png',
	'hxk' 			=> 'hxk.png',
	'hxs' 			=> 'hxs.png',
	'hxt' 			=> 'hxt.png',
	'icm' 			=> 'icm.png',
	'inf' 			=> 'ini.png',
	'ini' 			=> 'ini.png',
	'ins' 			=> 'ins.png',
	'iqy' 			=> 'iqy.png',
	'isp' 			=> 'ins.png',
	'its' 			=> 'its.png',
	'jar' 			=> 'jar.png',
	'jbf' 			=> 'jbf.png',
	'jfif' 			=> 'jpg.png',
	'jif' 			=> 'jpg.png',
	'job' 			=> 'job.png',
	'jpeg'			=> 'jpg.png',
	'jpg' 			=> 'jpg.png',
	'js' 			=> 'js.png',
	'jse' 			=> 'js.png',
	'lex'			=> 'ost.png',
	'lnk' 			=> 'lnk.png',
	'local' 		=> 'dll.png',
	'manifest'		=> 'dll.png',
	'm1v' 			=> 'avi.png',
	'm3u' 			=> 'avi.png',
	'mad' 			=> 'mad.png',
	'mat' 			=> 'mat.png',
	'mdb' 			=> 'mdb.png',
	'mht' 			=> 'mht.png',
	'mid' 			=> 'avi.png',
	'midi' 			=> 'avi.png',
	'mml' 			=> 'mml.png',
	'mmw' 			=> 'mml.png',
	'mp2' 			=> 'avi.png',
	'mp3' 			=> 'mp3.png',
	'mpa' 			=> 'avi.png',
	'mpe' 			=> 'avi.png',
	'mpeg'			=> 'avi.png',
	'mpg' 			=> 'avi.png',
	'msc' 			=> 'msc.png',
	'msg' 			=> 'msg.png',
	'msi' 			=> 'msi.png',
	'msstyles'		=> 'theme.png',
	'ncd' 			=> 'ncd.png',
	'nct' 			=> 'ncd.png',
	'nfo' 			=> 'nfo.png',
	'ocx' 			=> 'dll.png',
	'opc' 			=> 'prf.png',
	'ost' 			=> 'ost.png',
	'otf' 			=> 'otf.png',
	'pas' 			=> 'pas.png',
	'pdi' 			=> 'pdi.png',
	'pdf' 			=> 'pdf.png',
	'pfm' 			=> 'pfm.png',
	'pif' 			=> 'pif.png',
	'php' 			=> 'php.png',
	'php3' 			=> 'php.png',
	'php4' 			=> 'php.png',
	'phps' 			=> 'php.png',
	'phtml' 		=> 'php.png',
	'pip' 			=> 'ost.png',
	'pmc' 			=> 'pmc.png',
	'pnf' 			=> 'dll.png',
	'png' 			=> 'gif.png',
	'pot' 			=> 'pot.png',
	'ppk' 			=> 'ppk.png',
	'ppt' 			=> 'ppt.png',
	'prc' 			=> 'sql.png',
	'prf' 			=> 'prf.png',
	'psp' 			=> 'psp.png',
	'pst' 			=> 'ost.png',
	'pub' 			=> 'pub.png',
	'rar' 			=> 'rar.png',
	'rc' 			=> 'rc.png',
	'rct' 			=> 'rct.png',
	'rdp' 			=> 'rdp.png',
	'reg'			=> 'reg.png',
	'res'			=> 'res.png',
	'resx'			=> 'resx.png',
	'rmi' 			=> 'avi.png',
	'rtf' 			=> 'doc.png',
	'scr'			=> 'exe.png',
	'sdb'			=> 'dll.png',
	'sdl'			=> 'sdl.png',
	'shtm'			=> 'html.png',
	'shtml' 		=> 'html.png',
	'sln' 			=> 'sln.png',
	'snd' 			=> 'avi.png',
	'sql' 			=> 'sql.png',
	'suo' 			=> 'suo.png',
	'swf' 			=> 'swf.png',
	'tar' 			=> 'zip.png',
	'tdf' 			=> 'tdf.png',
	'tdl' 			=> 'tdl.png',
	'theme' 		=> 'theme.png',
	'tif' 			=> 'tiff.png',
	'tiff' 			=> 'tiff.png',
	'tgz' 			=> 'zip.png',
	'ttf' 			=> 'ttf.png',
	'txt' 			=> 'txt.png',
	'url' 			=> 'url.png',
	'vb' 			=> 'vb.png',
	'vbproj' 		=> 'vbproj.png',
	'vbs' 			=> 'vbs.png',
	'vcf' 			=> 'vcf.png',
	'vsdisco' 		=> 'disco.png',
	'vsmacros' 		=> 'vsmacros.png',
	'vxd' 			=> 'dll.png',
	'wab' 			=> 'wab.png',
	'wav' 			=> 'avi.png',
	'wax' 			=> 'avi.png',
	'wm' 			=> 'avi.png',
	'wma' 			=> 'avi.png',
	'wmf' 			=> 'gif.png',
	'wmv' 			=> 'avi.png',
	'wmx' 			=> 'avi.png',
	'wpl' 			=> 'wpl.png',
	'wri' 			=> 'wri.png',
	'wsc'			=> 'wsc.png',
	'wsf'			=> 'vbs.png',
	'wvx' 			=> 'avi.png',
	'xfm' 			=> 'dpr.png',
	'xla' 			=> 'xla.png',
	'xls' 			=> 'xls.png',
	'xml' 			=> 'xml.png',
	'xsd' 			=> 'xsd.png',
	'xsl' 			=> 'xsl.png',
	'xslt' 			=> 'xslt.png',
	'xsn' 			=> 'xsn.png',
	'z' 			=> 'zip.png',
	'zip' 			=> 'zip.png',
	'zup' 			=> 'fdb.png'
);

// Size Groups
$SizeGroups = Array(
	1 => _("Zero"),
	2 => _("Tiny"),
	3 => _("Small"),
	4 => _("Medium"),
	5 => _("Large"),
	6 => _("Huge"),
	7 => _("Gigantic"),
	9 => _("Folders")
);

// Date Groups
$DateGroups = Array(
	'01' => _("Today"),
	'02' => _("Yesterday"),
	'03' => _("Earlier this week"),
	'04' => _("Last Week"),
	'05' => _("Two weeks ago"),
	'06' => _("Earlier this month"),
	'07' => _("Last month"),
	'08' => _("Two months ago"),
	'09' => _("Earlier this year"),
	'10' => _("Last year"),
	'11' => _("Two years ago"),
	'12' => _("A long time ago"),
	'13' => _("Tomorrow"),
	'14' => _("Two days from now"),
	'15' => _("Later this week"),
	'16' => _("Later this month"),
	'17' => _("Next month"),
	'18' => _("Later this year"),
	'19' => _("Next year"),
	'20' => _("Two years from now"), // This is a bug in Windows XP, files with a date 2 year from now will not show up when grouping on file date!
	'21' => _("Sometime this millenia")
);

?>